==> wildfly-clustering-tomcat-19.0.0.Final-source-release.zip: wildfly-clustering-tomcat-19.0.0.Final/8.5/hotrod/src/test/java/org/wildfly/clustering/tomcat/hotrod/servlet/TomcatSession.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2020, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.wildfly.clustering.tomcat.hotrod.servlet;

import javax.servlet.http.HttpSession;

import org.wildfly.clustering.tomcat.servlet.ServletSession;

/**
 * @author Paul Ferraro
 */
public class TomcatSession implements ServletSession {

	private final HttpSession session;

	TomcatSession(HttpSession session) {
		this.session = session;
	}

	@Override
	public String getId() {
		return this.session.getId();
	}

	@Override
	public Object getAttribute(String name) {
		return this.session.getAttribute(name);
	}

	@Override
	public void setAttribute(String name, Object value) {
		this.session.setAttribute(name, value);
	}

	@Override
	public void invalidate() {
		this.session.invalidate();
	}
}

==> wildfly-clustering-tomcat-20.0.0.Final-source-release.zip: wildfly-clustering-tomcat-20.0.0.Final/10.1/hotrod/src/test/java/org/wildfly/clustering/tomcat/hotrod/servlet/TomcatSession.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2020, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.wildfly.clustering.tomcat.hotrod.servlet;

import org.wildfly.clustering.tomcat.servlet.ServletSession;

import jakarta.servlet.http.HttpSession;

/**
 * @author Paul Ferraro
 */
public class TomcatSession implements ServletSession {

	private final HttpSession session;

	TomcatSession(HttpSession session) {
		this.session = session;
	}

	@Override
	public String getId() {
		return this.session.getId();
	}

	@Override
	public Object getAttribute(String name) {
		return this.session.getAttribute(name);
	}

	@Override
	public void setAttribute(String name, Object value) {
		this.session.setAttribute(name, value);
	}

	@Override
	public void invalidate() {
		this.session.invalidate();
	}
}
